.. highlight:: shell

============
Installation
============


Stable release
--------------

To install potranslator, run this command in your terminal:

.. code-block:: console

    $ pip install potranslator

This is the preferred method to install potranslator, as it will always install the most recent stable release.


If you want to use the `Optional Features`_, you need to install this additional library transifex-client_:

.. code-block:: console

    $ pip install potranslator[transifex]

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/
.. _Optional Features: https://potranslator.readthedocs.io/en/latest/readme.html#optional-features
.. _transifex-client: https://pypi.python.org/pypi/transifex-client


From sources
------------

The sources for potranslator can be downloaded from the `Github repo`_.

You can either clone the public repository:

.. code-block:: console

    $ git clone git://github.com/SekouD/potranslator

Or download the `tarball`_:

.. code-block:: console

    $ curl  -OL https://github.com/SekouD/potranslator/tarball/master

Once you have a copy of the source, you can install it with:

.. code-block:: console

    $ python setup.py install


.. _Github repo: https://github.com/SekouD/potranslator
.. _tarball: https://github.com/SekouD/potranslator/tarball/master
